@@ -1,11 +1,12 @@
-import base64
 import configparser
+import hashlib
 import logging
+import glob
 import os
 import sys
 
 import qobuz_dl.spoofbuz as spoofbuz
-from qobuz_dl.color import CYAN, DF, GREEN, RED, YELLOW
+from qobuz_dl.color import GREEN, RED, YELLOW
 from qobuz_dl.commands import qobuz_dl_args
 from qobuz_dl.core import QobuzDL
 
@@ -21,26 +22,24 @@ else:
 
 CONFIG_PATH = os.path.join(OS_CONFIG, "qobuz-dl")
 CONFIG_FILE = os.path.join(CONFIG_PATH, "config.ini")
+QOBUZ_DB = os.path.join(CONFIG_PATH, "qobuz_dl.db")
 
 
 def reset_config(config_file):
     logging.info(f"{YELLOW}Creating config file: {config_file}")
     config = configparser.ConfigParser()
-    config["DEFAULT"]["email"] = input(f"{CYAN}Enter your email:\n-{DF} ")
-    config["DEFAULT"]["password"] = base64.b64encode(
-        input(f"{CYAN}Enter your password\n-{DF} ").encode()
-    ).decode()
+    config["DEFAULT"]["email"] = input("Enter your email:\n- ")
+    password = input("Enter your password\n- ")
+    config["DEFAULT"]["password"] = hashlib.md5(password.encode("utf-8")).hexdigest()
     config["DEFAULT"]["default_folder"] = (
-        input(
-            f"{CYAN}Folder for downloads (leave empy for default 'Qobuz Downloads')\n-{DF} "
-        )
+        input("Folder for downloads (leave empty for default 'Qobuz Downloads')\n- ")
         or "Qobuz Downloads"
     )
     config["DEFAULT"]["default_quality"] = (
         input(
-            f"{CYAN}Download quality (5, 6, 7, 27) "
+            "Download quality (5, 6, 7, 27) "
             "[320, LOSSLESS, 24B <96KHZ, 24B >96KHZ]"
-            f"\n(leave empy for default '6')\n-{DF} "
+            "\n(leave empty for default '6')\n- "
         )
         or "6"
     )
@@ -51,6 +50,7 @@ def reset_config(config_file):
     config["DEFAULT"]["og_cover"] = "false"
     config["DEFAULT"]["embed_art"] = "false"
     config["DEFAULT"]["no_cover"] = "false"
+    config["DEFAULT"]["no_database"] = "false"
     logging.info(f"{YELLOW}Getting tokens. Please wait...")
     spoofer = spoofbuz.Spoofer()
     config["DEFAULT"]["app_id"] = str(spoofer.getAppId())
@@ -64,6 +64,15 @@ def reset_config(config_file):
     )
 
 
+def remove_leftovers(directory):
+    directory = os.path.join(directory, "**", ".*.tmp")
+    for i in glob.glob(directory, recursive=True):
+        try:
+            os.remove(i)
+        except:  # noqa
+            pass
+
+
 def main():
     if not os.path.isdir(CONFIG_PATH) or not os.path.isfile(CONFIG_FILE):
         os.makedirs(CONFIG_PATH, exist_ok=True)
@@ -77,7 +86,7 @@ def main():
 
     try:
         email = config["DEFAULT"]["email"]
-        password = base64.b64decode(config["DEFAULT"]["password"]).decode()
+        password = config["DEFAULT"]["password"]
         default_folder = config["DEFAULT"]["default_folder"]
         default_limit = config["DEFAULT"]["default_limit"]
         default_quality = config["DEFAULT"]["default_quality"]
@@ -87,6 +96,7 @@ def main():
         og_cover = config.getboolean("DEFAULT", "og_cover")
         embed_art = config.getboolean("DEFAULT", "embed_art")
         no_cover = config.getboolean("DEFAULT", "no_cover")
+        no_database = config.getboolean("DEFAULT", "no_database")
         app_id = config["DEFAULT"]["app_id"]
         secrets = [
             secret for secret in config["DEFAULT"]["secrets"].split(",") if secret
@@ -98,11 +108,19 @@ def main():
         arguments = qobuz_dl_args().parse_args()
         if not arguments.reset:
             sys.exit(
-                f"{RED}Your config file is corrupted! Run 'qobuz-dl -r' to fix this"
+                f"{RED}Your config file is corrupted! Run 'qobuz-dl -r' to fix this."
             )
+
     if arguments.reset:
         sys.exit(reset_config(CONFIG_FILE))
 
+    if arguments.purge:
+        try:
+            os.remove(QOBUZ_DB)
+        except FileNotFoundError:
+            pass
+        sys.exit(f"{GREEN}The database was deleted.")
+
     qobuz = QobuzDL(
         arguments.directory,
         arguments.quality,
@@ -112,8 +130,8 @@ def main():
         quality_fallback=not arguments.no_fallback or not no_fallback,
         cover_og_quality=arguments.og_cover or og_cover,
         no_cover=arguments.no_cover or no_cover,
+        downloads_db=None if no_database or arguments.no_db else QOBUZ_DB,
     )
-
     qobuz.initialize_client(email, password, app_id, secrets)
 
     try:
@@ -127,12 +145,16 @@ def main():
         else:
             qobuz.interactive_limit = arguments.limit
             qobuz.interactive()
+
     except KeyboardInterrupt:
         logging.info(
             f"{RED}Interrupted by user\n{YELLOW}Already downloaded items will "
-            "be skipped if you try to download the same releases again"
+            "be skipped if you try to download the same releases again."
         )
 
+    finally:
+        remove_leftovers(qobuz.directory)
+
 
 if __name__ == "__main__":
     sys.exit(main())
