@@ -14,6 +14,8 @@ from pathvalidate import sanitize_filename
 import qobuz_dl.spoofbuz as spoofbuz
 from qobuz_dl import downloader, qopy
 from qobuz_dl.color import CYAN, OFF, RED, YELLOW, DF, RESET
+from qobuz_dl.exceptions import NonStreamable
+from qobuz_dl.db import create_db, handle_download_id
 
 WEB_URL = "https://play.qobuz.com/"
 ARTISTS_SELECTOR = "td.chartlist-artist > a"
@@ -60,6 +62,7 @@ class QobuzDL:
         quality_fallback=True,
         cover_og_quality=False,
         no_cover=False,
+        downloads_db=None,
     ):
         self.directory = self.create_dir(directory)
         self.quality = quality
@@ -72,6 +75,7 @@ class QobuzDL:
         self.quality_fallback = quality_fallback
         self.cover_og_quality = cover_og_quality
         self.no_cover = no_cover
+        self.downloads_db = create_db(downloads_db) if downloads_db else None
 
     def initialize_client(self, email, pwd, app_id, secrets):
         self.client = qopy.Client(email, pwd, app_id, secrets)
@@ -98,11 +102,18 @@ class QobuzDL:
         ).group(1)
 
     def download_from_id(self, item_id, album=True, alt_path=None):
+        if handle_download_id(self.downloads_db, item_id, add_id=False):
+            logger.info(
+                f"{OFF}This release ID ({item_id}) was already downloaded "
+                "according to the local database.\nUse the '--no-db' flag "
+                "to bypass this."
+            )
+            return
         try:
             downloader.download_id_by_type(
                 self.client,
                 item_id,
-                self.directory if not alt_path else alt_path,
+                alt_path or self.directory,
                 str(self.quality),
                 album,
                 self.embed_art,
@@ -111,7 +122,8 @@ class QobuzDL:
                 self.cover_og_quality,
                 self.no_cover,
             )
-        except requests.exceptions.RequestException as e:
+            handle_download_id(self.downloads_db, item_id, add_id=True)
+        except (requests.exceptions.RequestException, NonStreamable) as e:
             logger.error(f"{RED}Error getting release: {e}", exc_info=True)
 
     def handle_url(self, url):
@@ -177,12 +189,17 @@ class QobuzDL:
     def download_from_txt_file(self, txt_file):
         with open(txt_file, "r") as txt:
             try:
-                urls = txt.read().strip().split()
+                urls = [
+                    line.replace("\n", "")
+                    for line in txt.readlines()
+                    if not line.strip().startswith("#")
+                ]
             except Exception as e:
                 logger.error(f"{RED}Invalid text file: {e}")
                 return
             logger.info(
-                f'{YELLOW}qobuz-dl will download {len(urls)} urls from file: "{txt_file}"'
+                f"{YELLOW}qobuz-dl will download {len(urls)}"
+                f" urls from file: {txt_file}"
             )
             self.download_list_of_urls(urls)
 
